@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+from datetime import timedelta
 from typing import Any
 
 from robotlibcore import KeywordBuilder  # type: ignore
@@ -61,7 +61,7 @@ def get_function_list_from_keywords(keywords):
     return functions
 
 
-def keyword_line(keyword_arguments, keyword_types, method_name):
+def keyword_line(keyword_arguments, keyword_types, method_name) -> str:
     arguments_list = list()
     for argument in keyword_arguments:
         if isinstance(argument, tuple):
@@ -71,10 +71,12 @@ def keyword_line(keyword_arguments, keyword_types, method_name):
             if arg_type_str:
                 if default_value is None:
                     arg_type_str = f"Optional[{arg_type_str}]"
-                arg_str = arg_str + f": {arg_type_str}"
+                arg_str = f"{arg_str}: {arg_type_str}"
             if isinstance(default_value, str):
                 default_value = f"'{default_value}'"
-            arg_str = arg_str + f" = {default_value}"
+            if isinstance(default_value, timedelta):
+                default_value = f"timedelta(seconds={default_value.total_seconds()})"
+            arg_str = f"{arg_str} = {default_value}"
         else:
             arg_str = argument
             arg_type_str = get_type_string_from_argument(arg_str, keyword_types)
@@ -91,27 +93,46 @@ br: Any = Browser.Browser()
 function_list = get_function_list_from_keywords(br.get_keyword_names())
 
 
-pyi_boilerplate = """from concurrent.futures import Future
+pyi_boilerplate = """\
+import datetime
+from concurrent.futures import Future
+from datetime import timedelta
 from typing import (
     Any,
     Dict,
     List,
     Optional,
     Union,
+    Tuple,
 )
 
 from .utils.data_types import *
 
 
 class Browser:
+    timeout: Any = ...
+"""
+
+pyi_non_kw_methods = """\
+    def get_timeout(self, timeout: Union[timedelta, None]) -> float: ...
+    def convert_timeout(self, timeout: Union[timedelta, float]) -> float: ...
+    def millisecs_to_timestr(self, timeout: float)  -> str: ...
+
 """
 
 init_method = KeywordBuilder.build(br.__init__)
 with open("Browser/__init__.pyi", "w") as stub_file:
     stub_file.write(pyi_boilerplate)
-    stub_file.write(
-        keyword_line(
-            init_method.argument_specification, init_method.argument_types, "__init__"
-        )
+    init_string = keyword_line(
+        init_method.argument_specification, init_method.argument_types, "__init__"
     )
+    # init methods argument types that are contained within higher order types don't get
+    # import syntax stripped correctly so we fix them manually here
+    init_string = init_string.replace(
+        "Dict[Browser.utils.data_types.SupportedBrowsers, str]",
+        "Dict[SupportedBrowsers, str]",
+    )
+
+    stub_file.write(init_string)
     stub_file.writelines(function_list)
+    stub_file.write(pyi_non_kw_methods)
