@@ -82,6 +82,11 @@ class ViewportDimensions(TypedDict):
     height: int
 
 
+class RecordVideo(TypedDict, total=False):
+    dir: str
+    size: ViewportDimensions
+
+
 class HttpCredentials(TypedDict):
     """Sets the credentials for http basic-auth.
 
@@ -144,6 +149,17 @@ class Proxy(_Server, total=False):
     password: str
 
 
+class DownloadedFile(TypedDict):
+    """Downloaded file information.
+
+    ``saveAs`` is the path where downloaded file is saved.
+    ``suggestedFilename`` is the  contains the name suggested name for the download.
+    """
+
+    saveAs: str
+    suggestedFilename: str
+
+
 class SelectionType(Enum):
     """Enum that defines if the current id or all ids shall be returned.
 
